@@ -63,6 +63,7 @@ function run_tests()
   enq = xapian.Enquire(db)
 
   -- Check Xapian::BAD_VALUENO is wrapped suitably.
+  expect(xapian.BAD_VALUENO > 0, true)
   enq:set_collapse_key(xapian.BAD_VALUENO)
 
   it = db:positionlist_begin(1, "is")
@@ -343,7 +344,7 @@ function run_tests()
 
   mset:get_hit(0)
 
-  ---Test preservation of stopper set on query parser.
+  -- Test preservation of stopper set on query parser.
   function make_qp()
     queryparser = xapian.QueryParser()
     stopper = xapian.SimpleStopper()
@@ -360,6 +361,16 @@ function run_tests()
   end
   expect(terms, {"to"})
 
+  -- Test passing function for stopper.
+  queryparser = xapian.QueryParser()
+  queryparser:set_stopper(function (s) return string.len(s) < 3 end)
+  query = queryparser:parse_query('who to be')
+  terms = {}
+  for term in queryparser:stoplist() do
+    table.insert(terms, term:get_term())
+  end
+  expect(terms, {"to", "be"})
+
   -- Test preservation of stopper set on term generator.
   function make_tg()
     termgen = xapian.TermGenerator()
@@ -457,6 +468,16 @@ function run_tests()
   end
   expect(items, {{xapian.sortable_serialise(2), 2}, {xapian.sortable_serialise(1.5), 1}})
 
+  -- Test passing function as a matchspy.
+  spy_values = {}
+  enq:add_matchspy(
+    function (d)
+      table.insert(spy_values, xapian.sortable_unserialise(d:get_value(0)))
+    end)
+  enq:set_query(xapian.Query.MatchAll)
+  matches = enq:get_mset(1, 2)
+  expect(spy_values, {-1/0, -1/0, 2})
+
   -- Test exceptions
   ok,res = pcall(db.get_document, db, 0)
   expect(ok, false)
